@@ -19,9 +19,7 @@ from typing import Dict, Type
 from .base import ProvisioningTransport
 from .grpc import ProvisioningGrpcTransport
 from .grpc_asyncio import ProvisioningGrpcAsyncIOTransport
-from .rest import ProvisioningRestTransport
-from .rest import ProvisioningRestInterceptor
-
+from .rest import ProvisioningRestInterceptor, ProvisioningRestTransport
 
 # Compile a registry of transports.
 _transport_registry = OrderedDict()  # type: Dict[str, Type[ProvisioningTransport]]
