@@ -13,10 +13,10 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-import proto  # type: ignore
+from typing import MutableMapping, MutableSequence
 
 from google.protobuf import timestamp_pb2  # type: ignore
-
+import proto  # type: ignore
 
 __protobuf__ = proto.module(
     package="google.cloud.apigeeregistry.v1",
@@ -45,15 +45,15 @@ class CreateInstanceRequest(proto.Message):
             Required. The Instance.
     """
 
-    parent = proto.Field(
+    parent: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    instance_id = proto.Field(
+    instance_id: str = proto.Field(
         proto.STRING,
         number=2,
     )
-    instance = proto.Field(
+    instance: "Instance" = proto.Field(
         proto.MESSAGE,
         number=3,
         message="Instance",
@@ -69,7 +69,7 @@ class DeleteInstanceRequest(proto.Message):
             ``projects/*/locations/*/instances/*``.
     """
 
-    name = proto.Field(
+    name: str = proto.Field(
         proto.STRING,
         number=1,
     )
@@ -84,7 +84,7 @@ class GetInstanceRequest(proto.Message):
             ``projects/*/locations/*/instances/*``.
     """
 
-    name = proto.Field(
+    name: str = proto.Field(
         proto.STRING,
         number=1,
     )
@@ -116,33 +116,33 @@ class OperationMetadata(proto.Message):
             API version used to start the operation.
     """
 
-    create_time = proto.Field(
+    create_time: timestamp_pb2.Timestamp = proto.Field(
         proto.MESSAGE,
         number=1,
         message=timestamp_pb2.Timestamp,
     )
-    end_time = proto.Field(
+    end_time: timestamp_pb2.Timestamp = proto.Field(
         proto.MESSAGE,
         number=2,
         message=timestamp_pb2.Timestamp,
     )
-    target = proto.Field(
+    target: str = proto.Field(
         proto.STRING,
         number=3,
     )
-    verb = proto.Field(
+    verb: str = proto.Field(
         proto.STRING,
         number=4,
     )
-    status_message = proto.Field(
+    status_message: str = proto.Field(
         proto.STRING,
         number=5,
     )
-    cancellation_requested = proto.Field(
+    cancellation_requested: bool = proto.Field(
         proto.BOOL,
         number=6,
     )
-    api_version = proto.Field(
+    api_version: str = proto.Field(
         proto.STRING,
         number=7,
     )
@@ -172,7 +172,28 @@ class Instance(proto.Message):
     """
 
     class State(proto.Enum):
-        r"""State of the Instance."""
+        r"""State of the Instance.
+
+        Values:
+            STATE_UNSPECIFIED (0):
+                The default value. This value is used if the
+                state is omitted.
+            INACTIVE (1):
+                The Instance has not been initialized or has
+                been deleted.
+            CREATING (2):
+                The Instance is being created.
+            ACTIVE (3):
+                The Instance has been created and is ready
+                for use.
+            UPDATING (4):
+                The Instance is being updated.
+            DELETING (5):
+                The Instance is being deleted.
+            FAILED (6):
+                The Instance encountered an error during a
+                state change.
+        """
         STATE_UNSPECIFIED = 0
         INACTIVE = 1
         CREATING = 2
@@ -196,39 +217,39 @@ class Instance(proto.Message):
                 where the ``location`` must match InstanceConfig.location.
         """
 
-        location = proto.Field(
+        location: str = proto.Field(
             proto.STRING,
             number=1,
         )
-        cmek_key_name = proto.Field(
+        cmek_key_name: str = proto.Field(
             proto.STRING,
             number=2,
         )
 
-    name = proto.Field(
+    name: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    create_time = proto.Field(
+    create_time: timestamp_pb2.Timestamp = proto.Field(
         proto.MESSAGE,
         number=2,
         message=timestamp_pb2.Timestamp,
     )
-    update_time = proto.Field(
+    update_time: timestamp_pb2.Timestamp = proto.Field(
         proto.MESSAGE,
         number=3,
         message=timestamp_pb2.Timestamp,
     )
-    state = proto.Field(
+    state: State = proto.Field(
         proto.ENUM,
         number=4,
         enum=State,
     )
-    state_message = proto.Field(
+    state_message: str = proto.Field(
         proto.STRING,
         number=5,
     )
-    config = proto.Field(
+    config: Config = proto.Field(
         proto.MESSAGE,
         number=6,
         message=Config,
